@@ -43,6 +43,7 @@ class EnviarPedido(Enviar):
                 failure="{}/failure?next_url={}".format(notification_url, self.dados["next_url"])
             ),
             shipments=Shipments(
+                cost=self.formatador.formata_decimal(self.valor_envio, como_float=True),
                 receiver_address=ReceiverAddress(
                     street_name=unicode(self.pedido.endereco_entrega.endereco),
                     street_number=self.pedido.endereco_entrega.numero,
@@ -96,7 +97,8 @@ class EnviarPedido(Enviar):
             )
             for item in self.pedido.itens.all()
         ]
-        items.append(Item(title="Frete", quantity=1, currency_id="BRL", unit_price=self.formatador.formata_decimal(self.valor_envio, como_float=True)))
+        if self.valor_desconto:
+            items.append(Item(id="desconto", title="Desconto", quantity=1, currency_id="BRL", unit_price=self.formatador.formata_decimal((self.valor_desconto * -1), como_float=True)))
         return items
 
     def obter_situacao_do_pedido(self, status_requisicao):
